@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Util;
 
 our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -170,12 +170,12 @@ sub detect_pericmd_script {
                 }
             }
 
-            if ($str =~ /^my \%_pci_metas = \%\{ (.+) \};/m) {
+            if ($str =~ /^my \$_pci_metas = (.+);/m) {
                 my $pericmd_inline_metas = $1;
                 eval "\$pericmd_inline_metas = $1";
                 if ($@) {
                     push @{ $meta->{'func.notes'} },
-                        "Can't parse 'my %_pci_metas = ...' line: $@";
+                        "Can't parse 'my \$_pci_metas = ...' line: $@";
                 } else {
                     $meta->{'func.pericmd_inline_metas'} =
                         $pericmd_inline_metas;
@@ -223,7 +223,7 @@ Perinci::CmdLine::Util - Utility routines related to Perinci::CmdLine
 
 =head1 VERSION
 
-This document describes version 0.14 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2017-01-12.
+This document describes version 0.15 of Perinci::CmdLine::Util (from Perl distribution Perinci-CmdLine-Util), released on 2017-01-12.
 
 =head1 SYNOPSIS
 
